"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateItem = exports.parseItem = exports.generate = exports.parse = void 0;
function parse(configString) {
    const _items = configString.replace(/\n{3,}/, '\n\n').split('\n\n');
    return _items
        .map((_item) => {
        return parseItem(_item);
    })
        .filter((e) => !!e);
}
exports.parse = parse;
function generate(items) {
    const _items = items.map((item) => generateItem(item));
    return _items.join('\n\n');
}
exports.generate = generate;
function parseItem(itemText) {
    const _item = itemText.split('\n').reduce((item, text) => {
        if (/^\s.*#/.test(text)) {
            return item;
        }
        else if (!text.replace(/\s+/, '')) {
            return item;
        }
        const parts = text.trim().replace(/\s+/, ' ').split(' ');
        const key = parts[0];
        const value = parts.slice(1).join(' ');
        item[key] = value;
        return item;
    }, {});
    return _item.Host ? _item : null;
}
exports.parseItem = parseItem;
function generateItem(item) {
    const { Host, ...rest } = item;
    const mainLine = `Host ${Host}`;
    const subLines = Object.keys(rest).map((key) => {
        const value = rest[key];
        return `  ${key} ${value}`;
    });
    return [mainLine, ...subLines].join('\n');
}
exports.generateItem = generateItem;
